import datetime

import pytest
from django.db import connection
from django.test import override_settings
from django.test.utils import CaptureQueriesContext

from chrono.agendas.models import (
    Agenda,
    Booking,
    Desk,
    Event,
    MeetingType,
    Resource,
    TimePeriod,
    TimePeriodException,
    TimePeriodExceptionSource,
    UnavailabilityCalendar,
)
from chrono.utils.timezone import now
from tests.utils import login

pytestmark = pytest.mark.django_db


def test_manager_agenda_partial_bookings(app, admin_user):
    agenda = Agenda.objects.create(label='Foo bar', kind='events')
    event = Event.objects.create(start_datetime=now(), places=10, agenda=agenda)
    Booking.objects.create(event=event)

    app = login(app)
    resp = app.get('/manage/agendas/%s/edit' % agenda.pk)
    assert 'partial_bookings' not in resp.form.fields

    Event.objects.all().delete()
    resp = app.get('/manage/agendas/%s/edit' % agenda.pk)
    resp.form['partial_bookings'] = True
    resp = resp.form.submit().follow()

    resp = resp.click('New Event')
    assert 'places' not in resp.form.fields
